@@ -16,7 +16,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
     for _ in 0..student_num {
         let grade = rng.gen_range(min_grade..=max_grade);
         list += &grade.to_string();
-        list += "\n";
+        list += "\r\n";
     }
     
     set_clipboard(formats::Unicode,list).unwrap();
